@@ -9,12 +9,13 @@ vaznull <- function(N, web){
   #
   # implementor: Bernd Gruber <bernd.gruber@ufz.de> & Carsten Dormann
 
+  web <- as.matrix(empty(web)) # otherwise we cannot compute the crossproduct later on. 
+
   vaznull.fast <- function(web){
   
   	rs.p <- rowSums(web)/sum(web)
   	cs.p <- colSums(web)/sum(web)
   	P <- P1 <- tcrossprod(rs.p, cs.p)
-  
    
   #create only one new mat
   finalmat <- matrix(0, nrow(web), ncol(web))
@@ -53,11 +54,10 @@ vaznull <- function(N, web){
   }
 
   # vectorised call of vaznull.fast:
-
   replicate(N, vaznull.fast(web), simplify=FALSE)
 
 }
 #data(Safariland)
 #vaznull(1, Safariland)
 #system.time(vaznull(10, Safariland))
-#system.time(swap.web(10, Safariland))    
\ No newline at end of file
+#system.time(swap.web(10, Safariland))
\ No newline at end of file
