@@ -4,9 +4,11 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
     prey.lablength = NULL, clear = TRUE, xlabel = "", ylabel = "", 
     boxes = TRUE, circles = FALSE, circle.col = "black", circle.min = 0.2, 
     circle.max = 2, outerbox.border = "white", outerbox.col = "white", 
-    box.border = "black", box.col = "black", def.col="blue") 
+    box.border = "black", box.col = "black", def.col="blue", max.digits=4, NA.col="red") 
 {
+	backweb <- as.matrix(web)
     if (!is.matrix(web)) {
+        
         web <- as.matrix(web)
         warning("Object converted to matrix.")
     }
@@ -18,7 +20,7 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
     if (clear == TRUE) 
         web <- empty(web)
     if (type == "diagonal") {
-        require(vegan)
+        # require(vegan)
         web <- empty(web)
         ca <- cca(web)
         web <- web[order(summary(ca)$sites[, 1], decreasing = TRUE), 
@@ -36,22 +38,23 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
     if (n.pred > n.prey) {
         wx <- plotsize
         wy <- (plotsize)/n.pred * n.prey
-    }
-    else {
+    } else {
         wy <- plotsize
         wx <- (plotsize)/n.prey * n.pred
     }
     m.predsize = max(strwidth(colnames(web), units = "inches"))
     m.preysize = max(strwidth(rownames(web), units = "inches"))
     cellsize = wx/n.pred
-    if (substr(text, 1, 1) == "i") 
-        s <- as.character(max(web))
-    else s = "A"
+    if (substr(text, 1, 1) == "i") {
+        s <- as.character(round(max(web),max.digits))
+    } else {s = "A"}
     lettersize = strwidth(s, units = "inches")
     clratio = cellsize/lettersize
-    mm <- max(m.predsize, m.preysize)
-    par(pin = c(wx, wy), omi = c(0, 0, 0, 0), mai = c(mm, mm, 
-        0, 0))
+    #mm.pred <- max(m.predsize, m.preysize)
+  
+    #pin = c(wx, wy),
+    par( omi = c(0, 0, 0, 0), mai = c(m.predsize*0.4 * labsize *                 clratio+0.2, m.preysize*0.4 * labsize * clratio+0.2, 0, 0))
+      
     plot(1, type = "n", axes = FALSE, xlim = c(0, n.pred), ylim = c(0, 
         n.prey), asp = 1, xlab = xlabel, ylab = ylabel)
     rect(0, 0, n.pred, n.prey, col = outerbox.col, border = outerbox.border)
@@ -65,8 +68,7 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
                   cn <- paste(c(substr(s, 1, min(pop - 1, 9)), 
                     "\n", substr(s, pop + 1, pop + 9)), sep = "", 
                     collapse = "")
-                }
-                else {
+                } else {
                   if (!is.null(pred.lablength)) {
                     cn <- substr(s, 1, pred.lablength)
                   }
@@ -91,12 +93,10 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
                   cr <- paste(c(substr(s, 1, min(pop - 1, 9)), 
                     "\n", substr(s, pop + 1, pop + 9)), sep = "", 
                     collapse = "")
-                }
-                else {
+                } else {
                   if (!is.null(prey.lablength)) {
                     cr <- substr(s, 1, prey.lablength)
-                  }
-                  else {
+                  } else {
                     cr <- s
                   }
                 }
@@ -114,12 +114,10 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
         c = start[2]
         web[r, c] = -comp
         for (i in 1:n.r) {
-            if (web[i, c] > 0) 
-                web <- cross(web, c(i, c), comp)
+            if (web[i, c] > 0) web <- cross(web, c(i, c), comp)
         }
         for (i in 1:n.c) {
-            if (web[r, i] > 0) 
-                web <- cross(web, c(r, i), comp)
+            if (web[r, i] > 0) web <- cross(web, c(r, i), comp)
         }
         return(web)
     }
@@ -131,43 +129,52 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
         comp = comp + 1
     }
     w <- abs(w)
-    nl <- length(unique(rank(web))) - 1
+    nl <- max(length(unique(rank(web))) - 1,1)
     lev <- as.numeric(names(table(web)))
     max.web <- max(web)
     for (i in 1:n.prey) {
         for (ii in 1:n.pred) {
-            if (substr(square, 1, 1) == "c") 
+            if (substr(square, 1, 1) == "c") {
                 c = 1 - (w[n.prey - i + 1, ii]) * (1/(max(w)))
-            else if (substr(square, 1, 1) == "i") 
-                c = (1 - (which(lev == web[n.prey - i + 1, ii]) - 
-                  1)/nl) 
-            else if (substr(square, 1, 1) == "b") 
-                c = floor((1 - web[n.prey - i + 1, ii]/mcol))
-            else c = 1
-            if (substr(square, 1, 1) == "b" & c == 0) 
-                c = box.col
-            else c = gray(c)
-            
-            if (substr(square, 1, 1) == "d") c=def.col[ which(lev == web[n.prey - i + 1, ii])]
+            } else {
+              if (substr(square, 1, 1) == "i") {
+                c = (1 - (which( round(lev,6) == round(web[n.prey - i + 1, ii],6)) - 1)/nl) 
+              } else {
+                if (substr(square, 1, 1) == "b") {
+                  c = floor((1 - web[n.prey - i + 1, ii]/mcol))
+                } else { 
+                  c = 1
+                }
+              }
+            }
+            if (substr(square, 1, 1) == "b" & c == 0) {
+              c = box.col
+            } else {
+              c = gray(c)
+            }
             
+            if (substr(square, 1, 1) == "d") c=def.col[ which(round(lev,6) == round(web[n.prey - i + 1, ii],6))]
             
+            if (is.na(backweb[n.prey-i+1,ii])) c <- NA.col
             if (circles == TRUE) 
                 c = outerbox.col
             if (boxes == TRUE) 
                 rect(ii - 1, i - 1, ii, i, col = c, border = box.border)
-            if (circles == TRUE && web[n.prey - i + 1, ii] > 
-                0) 
+            if (circles == TRUE && web[n.prey - i + 1, ii] >  0) {
                 points(ii - 0.5, i - 0.5, pch = 21, col = circle.col, 
-                  bg = circle.col, cex = circle.min + (circle.max * 
-                    web[n.prey - i + 1, ii]/max.web))
+                  bg = circle.col, cex = circle.min + 
+                  (circle.max * web[n.prey - i + 1, ii]/max.web))
+            }
             tc <- ""
             if (substr(text, 1, 1) == "i") {
                 if (web[n.prey - i + 1, ii] > 0) 
-                  tc <- web[n.prey - i + 1, ii]
-            }
-            else if (substr(text, 1, 1) == "c") {
-                if (w[n.prey - i + 1, ii] > 0) 
+                  tc <- round(web[n.prey - i + 1, ii],max.digits)
+            } else {
+              if (substr(text, 1, 1) == "c") {
+                if (w[n.prey - i + 1, ii] > 0) {
                   tc <- LETTERS[w[n.prey - i + 1, ii]]
+                }
+              }
             }
             text(ii - 0.5, i - 0.5, tc, col = textcol, cex = 1 * 
                 textsize * clratio * 0.5, adj = c(0.5, 0.5))
@@ -186,4 +193,22 @@ visweb <- function (web, type = "nested", prednames = TRUE, preynames = TRUE,
                 lwd = 3)
         }
     }
-}
\ No newline at end of file
+}
+
+
+#require(bipartite)
+#x<-matrix(c(1,0,0,1,
+#0,1,0,0,
+#1,1,1,0,
+#0,0,1,1,
+#1,0,0,0,
+#1,1,1,1),nrow=6,ncol=4)
+# 
+#colnames(x)<-c("A","B","C","D")
+#rownames(x)<-c("Aaron","Betty","Charles","Dina","Elias","Fiona")
+#visweb(x,type="none",circles=TRUE, clear=F)
+#
+#
+
+#m <- matrix(3,3,4)
+
